rcmpy.commands package — docs

Skip to main content
`Ctrl`+`K`

# rcmpy.commands package

## Submodules

## rcmpy.commands.all module

A module aggregating package commands.

rcmpy.commands.all.commands() → list[tuple[str, str, Callable[[ArgumentParser], Callable[[Namespace], int]]]]

  Get this package’s commands.

## rcmpy.commands.apply module

An entry-point for the ‘apply’ command.

rcmpy.commands.apply.add_apply_cmd(parser: ArgumentParser) → Callable[[Namespace], int]

  Add apply-command arguments to its parser.

rcmpy.commands.apply.apply_cmd(args: Namespace) → int

  Execute the apply command.

rcmpy.commands.apply.apply_env(args: Namespace, env: Environment) → int

  Apply pending changes from the environment.

## rcmpy.commands.common module

A module for common argument-parsing methods.

rcmpy.commands.common.add_default_flag(parser: ArgumentParser) → None

  Adds a default-flag argument.

rcmpy.commands.common.run_env_command(args: Namespace, cmd: Callable[[Namespace, Environment], int]) → int

  Run a command with the environment instance loaded.

## rcmpy.commands.dump module

An entry-point for the ‘dump’ command.

rcmpy.commands.dump.add_dump_cmd(_: ArgumentParser) → Callable[[Namespace], int]

  Add dump-command arguments to its parser.

rcmpy.commands.dump.dump_cmd(args: Namespace) → int

  Execute the dump command.

rcmpy.commands.dump.dump_env(_: Namespace, env: Environment) → int

  Dump information about the environment.

## rcmpy.commands.use module

An entry-point for the ‘use’ command.

rcmpy.commands.use.add_use_cmd(parser: ArgumentParser) → Callable[[Namespace], int]

  Add use-command arguments to its parser.

rcmpy.commands.use.use_cmd(args: Namespace) → int

  Execute the use command.

## rcmpy.commands.variant module

An entry-point for the ‘variant’ command.

rcmpy.commands.variant.add_variant_cmd(parser: ArgumentParser) → Callable[[Namespace], int]

  Add variant-command arguments to its parser.

rcmpy.commands.variant.variant_cmd(args: Namespace) → int

  Execute the variant command.

## rcmpy.commands.watch module

An entry-point for the ‘watch’ command.

rcmpy.commands.watch.add_watch_cmd(parser: ArgumentParser) → Callable[[Namespace], int]

  Add watch-command arguments to its parser.

rcmpy.commands.watch.watch_cmd(args: Namespace) → int

  Execute the watch command.

## Module contents